/*
    Copyright (C) 2016 Harald Sitter <sitter@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
    version 2 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.

    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
    Boston, MA 02110-1301, USA.
*/

#include <QStandardPaths>
#include <QTest>

#include <kicontheme.h>

class KIconTheme_UnitTest : public QObject
{
    Q_OBJECT

private Q_SLOTS:
    void initTestCase()
    {
        QStandardPaths::setTestModeEnabled(true);
    }

    void init()
    {
        KIconTheme::forceThemeForTests(QString()); // Reset override.
    }

    void testForceThemeForTests()
    {
        auto forcedName = QStringLiteral("kitten");
        auto resolvedCurrent = KIconTheme::current();
        QVERIFY2(KIconTheme::current() != forcedName,
                 "current theme initially expected to not be mangled");
        // Force a specific theme.
        KIconTheme::forceThemeForTests(forcedName);
        QCOMPARE(KIconTheme::current(), forcedName);
        // Reset override.
        KIconTheme::forceThemeForTests(QString());
        QCOMPARE(KIconTheme::current(), resolvedCurrent);
        // And then override again to make sure we still can.
        KIconTheme::forceThemeForTests(forcedName);
        QCOMPARE(KIconTheme::current(), forcedName);
    }
};

QTEST_MAIN(KIconTheme_UnitTest)

#include "kicontheme_unittest.moc"
